@@ -1,6 +1,6 @@
 #!/bin/sh
 # Check whether a PR has been analyzed within the acknowledgment period.
-# Copyright (C) 1993, 1994, 1995 Free Software Foundation, Inc.
+# Copyright (C) 1993, 1994, 1995, 1999 Free Software Foundation, Inc.
 # Contributed by Brendan Kehoe (brendan@cygnus.com).
 #
 # This file is part of GNU GNATS.
@@ -19,34 +19,73 @@
 # along with GNU GNATS; see the file COPYING.  If not, write to
 # the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
-# Arguments coming in are:
-#
-# $1 - response time
-# $2 - PR number
-# $3 - path to the PR file
-# $4 - submitter-id
-# $5 - full name of the submitter
-# $6 - contact for the submitter
-# $7 - address for GNATS_ADMIN
+prog=`basename $0`
+USAGE="Usage: $prog [-h] [-d gnats_root] arguments
+
+ Arguments coming in are (all are required):
+
+ 1 - response time
+ 2 - PR number
+ 3 - path to the PR file
+ 4 - submitter-id
+ 5 - full name of the submitter
+ 6 - contact for the submitter
+ 7 - address for GNATS_ADMIN
+"
 
 PATH=/bin:/usr/bin; export PATH
 
-GNATS_ROOT=xGNATS_ROOTx
+if [ $# -eq 0 ]
+then
+  echo "$USAGE" >&2
+  exit 1
+fi
+
+if [ "$1" = "-h" -o "$1" = "--help" ]
+then
+  echo "$USAGE"
+  exit 0
+fi
+
+# process command line options
+while [ $# -gt 7 ]; do
+  case "$1" in
+    -d | --directory)
+      if [ $# -eq 8 ]
+      then 
+        echo "ERROR: value required for $1 option" >&2
+        echo "$USAGE" >&2
+        exit 1
+      fi
+      shift 
+      GNATS_ROOT="$1" ;;
+    -d=* | --directory=*) GNATS_ROOT="`echo $1 | sed 's/^[-a-z]*=//'`" ;;
+
+    -*) echo "$USAGE" >&2; exit 1 ;;
+  esac
+  shift
+done
+
+GNATS_ROOT=${GNATS_ROOT:-xGNATS_ROOTx} ; export GNATS_ROOT
 VERSION=xVERSIONx
 LIBEXECDIR=xLIBEXECDIRx
 MAIL_AGENT="xMAIL_AGENTx"
 GNATS_USER="xGNATS_USERx"
 
+STATES_FILE=${GNATS_ROOT}/gnats-adm/states
+
 # Newer config information?
 [ -f ${GNATS_ROOT}/gnats-adm/config ] && . ${GNATS_ROOT}/gnats-adm/config
 
 if [ $# != 7 ]; then
-  echo "$0: called with the incorrect number of arguments"
+  echo "ERROR: $prog called with the incorrect number of arguments" >&2
+  echo "$USAGE" >&2
   exit 1
 fi
  
 if [ ! -d $GNATS_ROOT ]; then
-  echo "$0: GNATS base directory $GNATS_ROOT does not exist."
+  echo "ERROR: $prog GNATS base directory $GNATS_ROOT does not exist." >&2
+  echo "$USAGE" >&2
   exit 1
 fi
 
@@ -70,7 +109,37 @@ Subject: mail output from at-pr
 "
 fi
 
-if [ "$STATE" = "open" ]; then
+# Read the default (first) state from the gnats-adm/states file.
+get_default_state ()
+{
+    if [ ! -f ${STATES_FILE} ]; then
+      echo "open";
+      return 0;
+    fi
+
+    LINES=`grep '^[A-Za-z0-9_.-]' ${STATES_FILE} 2>/dev/null`
+
+    if [ -z "${LINES}" ]; then
+      echo "open"
+      return 0;
+    fi
+
+    # else get the first state
+
+    # Yes, this is as gross as you think it is.
+    # Tried to use `read', but that didn't work...
+    SAVED_IFS=${IFS}
+    IFS="${IFS}:"
+    for name in ${LINES}
+    do
+        echo "${name}"
+        IFS=${SAVED_IFS}
+        break
+    done
+}
+OPEN_STATE=`get_default_state`
+
+if [ "$STATE" = "${OPEN_STATE}" ]; then
   $MAIL_AGENT << __EOF__
 ${STEALTH_HEADER}From: $GNATS_USER (GNATS Management)
 To: $6, $RESP_ADDR, $7
