@@ -40,7 +40,7 @@ int remember_krb_auth_ret = 0; /* yes, I like lisp. go away. */
 FILE *serv_write, *serv_read;
 
 /* Where our results should go.  */
-FILE *outfp = stdout;
+FILE *outfp = NULL;
 
 /* What the server said back to us.  */
 char *reply = NULL;
