@@ -49,27 +49,43 @@ extern char *mail_agent;
 
 /* Default size of char arrays.  */
 #define STR_MAX 255
+#define STR_MAXLONG 512
 
 
 /* These files are currently live under GNATS_ADM.  */
 
+/* Ordered list of possible states, with optional brief descriptions.  */
+#define STATES "states"
+
+/* Ordered list of possible classes, with optional brief descriptions.  */
+#define CLASSES "classes"
+
 /* List of possible categories, with notification information.  */
-#define CATEGORIES "/categories"
+#define CATEGORIES "categories"
 
 /* List of submitters (e.g., members of a team, sites on the net, customers,
    etc.) which can send in bug reports via send-pr.  */
-#define SUBMITTERS "/submitters"
+#define SUBMITTERS "submitters"
 
 /* List of names (and possibly email addresses) for the different people
    responsible for a given PR.  `responsible' is somewhat of a misnomer, since
    the person responsible may well be a local user.  But the name stuck.  */
-#define RESPONSIBLE_FILE  "/responsible"
+#define RESPONSIBLE_FILE  "responsible"
 
 /* File used to provide fast lookups on certain fields.  */
-#define INDEX "/index"
+#define INDEX "index"
 
 /* List of the access allowed for the GNATS daemon.  */
 #define ACCESS_FILE		"gnatsd.conf"
 
+/* List of the access allowed for the GNATS daemon. (relative to gnats-db/gnats-adm) */
+#define DB_ACCESS_FILE		"gnatsd.access"
+
+/* List of the access allowed for the GNATS daemon. (fully-qualified) */
+#define GLOBAL_ACCESS_FILE	"/etc/gnatsd.access"
+
 /* Pathnames of GNATS-specific commands and tools.  */
 extern char *bindir;
+
+/* GNATS config file for list-config.  */
+#define CONFIG "config"
