@@ -138,8 +138,9 @@ gnats (fp)
 	  log_msg (LOG_INFO, 1, "responsible entry not found for",
 		   person);
 	  responsible = (Responsible *) xmalloc (sizeof (Responsible));
-	  responsible->key = responsible->alias = responsible->fullname
-	    = strdup (person);
+	  responsible->key = strdup (person);
+	  responsible->alias = strdup (person);
+	  responsible->fullname = strdup (person);
 	}
     }
 
@@ -596,13 +597,13 @@ reply_to_submitter (responsible)
   if (*reply_to == '\0')
     reply_to = header_value (FROM);
   fprintf (msg, "To: %s", reply_to);
-  fprintf (msg, "From: %s\n", gnats_admin);
+  fprintf (msg, "From: %s\n", gnats_addr);
   subject = header_value (SUBJECT);
   fprintf (msg, "Subject: Re: %s/%s: %s",
 	   field_value (CATEGORY), field_value (NUMBER), subject);
   if (*subject == '\0')
     fprintf (msg, "\n");
-  fprintf (msg, "Reply-To: %s, %s\n", gnats_admin, responsible);
+  fprintf (msg, "Reply-To: %s, %s\n", gnats_addr, responsible);
   fprintf (msg, "In-Reply-To: Your message of %s\t%s\n",
 	   header_value (DATE), header_value (MSG_ID));
 
@@ -699,6 +700,20 @@ append_notify (person)
   return NULL;
 }
 
+static void
+try_append_notify (notify, string)
+     char *notify;
+     char *string;
+{
+  char *try = append_notify (string);
+  if (try != NULL)
+    {
+      strcat (notify, try);
+      xfree (try);
+    }
+}
+
+
 /* Generate a bug report and send it off to the responsible person.  */
 static void
 notify_responsible (responsible, subcontact, subnotify, cnotify,
@@ -709,47 +724,30 @@ notify_responsible (responsible, subcontact, subnotify, cnotify,
 {
   FILE *msg;
   char *notify = (char *) alloca (BUFSIZ); /* FIXME - huge */
-  char *subc = NULL, *subn = NULL, *cnote = NULL, *xnotify = NULL, *gnotify, *p;
   char buf[GNATS_TIME_LENGTH];
   Header_Name i;
 
   notify[0] = '\0';
 
-  subc = append_notify (subcontact);
-  if (subc)
-    {
-      strcat (notify, subc);
-      xfree (subc);
-    }
-  subn = append_notify (subnotify);
-  if (subn)
-    {
-      strcat (notify, subn);
-      xfree (subn);
-    }
-  cnote = append_notify (cnotify);
-  if (cnote)
-    {
-      strcat (notify, cnote);
-      xfree (cnote);
-    }
+  try_append_notify (notify, subcontact);
+  try_append_notify (notify, subnotify);
+  try_append_notify (notify, cnotify);
 
-  gnotify = (char *) strdup (header_value (X_GNATS_NOTIFY));
-  xnotify = append_notify (gnotify);
-  if (xnotify)
-    {
-      strcat (notify, xnotify);
-      xfree (xnotify);
-    };
-  xfree (gnotify);
+  {
+    char *gnotify = (char *) strdup (header_value (X_GNATS_NOTIFY));
+    try_append_notify (notify, gnotify);
+    xfree (gnotify);
+  }
+
+  { 
+    /* Strip away the trailing comma that was added by append_notify (). */
+    char *p = (char *) strrchr (notify, ',');
+    if (p != NULL)
+      {
+	*p = '\0';
+      }
+  }
 
-  /* Strip away the trailing comma that was added by append_notify (). */
-  p = (char *) strrchr (xnotify, ',');
-  if (p != NULL)
-    {
-      *p = '\0';
-    }
-  
   block_signals ();
 
   msg = open_mail_file ();
@@ -775,7 +773,7 @@ notify_responsible (responsible, subcontact, subnotify, cnotify,
 	     header_value (DATE), header_value (MSG_ID));
 
 #else /* ! DONT_USE_RESENT */
-  fprintf(msg, "Resent-From: %s (GNATS Management)\n", gnats_admin);
+  fprintf(msg, "Resent-From: %s (GNATS Filer)\n", gnats_addr);
   fprintf(msg, "Resent-To: %s\n", responsible);
   if (*notify)
     fprintf(msg, "Resent-Cc: %s\n", notify);
@@ -783,7 +781,7 @@ notify_responsible (responsible, subcontact, subnotify, cnotify,
     char * reply_to = header_value (REPLY_TO);
     if (! (reply_to && *reply_to))
       reply_to = header_value (FROM);
-    fprintf(msg, "Resent-Reply-To: %s, %s", gnats_admin, reply_to);
+    fprintf(msg, "Resent-Reply-To: %s, %s", gnats_addr, reply_to);
   }
   for (i = RETURN_PATH; i < NUM_HEADER_ITEMS; i++)
     {
