@@ -35,7 +35,7 @@ int is_client = 0;
 char *catfile = (char *)NULL;
 
 /* Where the results of query-pr should go.  */
-FILE *outfile = stdout;
+FILE *outfile = NULL;
 
 /* If TRUE, we should sort the index list by number.  */
 int sort_numerical = FALSE;
@@ -296,6 +296,8 @@ main (argc, argv)
   int optc, i;
   Categories *clist, *c;
 
+  outfile = stdout;
+  
   program_name = (char *) basename (argv[0]);
 
   while ((optc = getopt_long (argc, argv, "o:c:hd:nV",
