@@ -36,6 +36,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
 #include "config.h"
 #include "gnats.h"
 #include "query.h"
+#include "db_conf.h"
 
 void usage (), version();
 
@@ -51,6 +52,7 @@ time_t migration, freeze, lastfreeze;
 
 struct option long_options[] =
 {
+  {"directory", 1, NULL, 'd'},
   {"verbose", 0, NULL, 'v'},
   {"version", 0, NULL, 'V'},
   {NULL, 0, NULL, 0}
@@ -59,6 +61,9 @@ struct option long_options[] =
 /* If 1, we're running the daemon.  */
 int is_daemon = 0;
 
+/* If 1, we're running a network client.  */
+int is_client = 0;
+
 time_t
 got_closed (p)
      char *p;
@@ -128,7 +133,7 @@ do_prlist ()
   int len = strlen (gnats_root);
 
   for (i = index_chain; i ; i = i->next)
-    if (strcmp (i->state, "closed") == 0
+    if (check_state_type (i->state, "closed")
 	&& regcmp ("no", i->confidential) == 0)
       {
 	sprintf (path, "%s/%s/%s", gnats_root, i->category, i->number);
@@ -166,11 +171,15 @@ main (argc, argv)
   program_name = basename (argv[0]);
   verbose = 0;
 
-  while ((optc = getopt_long (argc, argv, "hvV",
+  while ((optc = getopt_long (argc, argv, "hvVd:",
 			      long_options, (int *) 0)) != EOF)
     {
       switch (optc)
 	{
+	case 'd':
+	  gnats_root = optarg;
+	  break;
+
 	case 'V':
 	  version ();
 	  exit (0);
@@ -206,9 +215,8 @@ main (argc, argv)
       fprintf (stderr, "Last freeze:    %d\n", lastfreeze);
     }
 
-  configure ();
-  init_gnats ();
-
+  init_gnats (program_name);
+  
   index_chain = get_index ();
   if (index_chain == NULL)
     {
@@ -221,6 +229,7 @@ main (argc, argv)
 
   do_prlist ();
 
+  free_db_conf();
   exit (0);
 }
 
@@ -228,7 +237,7 @@ void
 usage (x)
   int x;
 {
-  fprintf (stderr, "Usage: %s [-v|--verbose] [-V|--version] migration freeze lastfreeze\n", program_name);
+  fprintf (stderr, "Usage: %s [-v|--verbose] [-V|--version] [-d gnats_root] migration freeze lastfreeze\n", program_name);
   fprintf (stderr, "      -v | --verbose     Print the name of each PR as we check it.\n");
   fprintf (stderr, "      -V | --version     Print version and exit.\n");
   fprintf (stderr, "      To use this to find the PRs fixed in a particular release, run it as\n");
