@@ -150,6 +150,9 @@ extern int debug_level;
 /* If 1, we're running the daemon.  */
 extern int is_daemon;
 
+/* If 1, we're running a network client.  */
+extern int is_client;
+
 /* File to log all messages to.  */
 extern FILE *gnats_logfile;
 
@@ -162,6 +165,9 @@ extern char *gnats_root;
 /* The definition of GNATS_USER as generated for config.c.  */
 extern char *gnats_user;
 
+/* The default category, read from the config file.  */
+extern char *default_category;
+
 /* Possible values for the logging mode.  Note "syslog" will only be used
    if the system supports it---otherwise it will relegate to "mail".  */
 typedef enum
@@ -198,6 +204,8 @@ extern void get_reply			PARAMS((void));
 extern void client_init			PARAMS((void));
 extern void client_exit			PARAMS((void));
 extern void safe_exit			PARAMS((void));
+extern void client_chdb 	        PARAMS((void));
+extern void client_user 	        PARAMS((char *, char *));
 
 /* in config.c */
 extern void configure			PARAMS((void));
@@ -233,24 +241,28 @@ extern Index *get_index			PARAMS((void));
 extern void write_index			PARAMS((Index*));
 extern void free_index			PARAMS((Index *));
 extern void free_index_entry		PARAMS((Index *));
+extern char *lookup_pr_path             PARAMS((char*));
 
 /* in internal.c */
 extern void block_signals               PARAMS((void));
 extern void unblock_signals             PARAMS((void));
 extern void add_to_index                PARAMS((void));
-extern int is_gnats_locked               PARAMS((void));
-extern int lock_gnats                    PARAMS((void));
-extern int unlock_gnats                  PARAMS((void));
+extern int is_gnats_locked              PARAMS((void));
+extern int lock_gnats                   PARAMS((void));
+extern int unlock_gnats                 PARAMS((void));
 extern void punt                        PARAMS((int, ...));
 extern int copy_file                    PARAMS((char *, char *));
 extern void add_to_index		PARAMS((void));
 extern int gnats_locked			PARAMS((void));
+extern char *get_prid_from_path         PARAMS((char*));
+extern char *get_cat_prid_from_path     PARAMS((char*));
+extern char *get_lock_path              PARAMS((char*));
 
 /* in lists.c */
 extern int get_gnats_file		PARAMS((unsigned int, char*));
 
 /* in misc.c */
-extern void init_gnats			PARAMS((void));
+extern void init_gnats			PARAMS((char *));
 extern void log_msg			PARAMS((int, int, ...));
 extern char *get_next_field		PARAMS((char *, char *, int));
 extern int read_string			PARAMS((char *, FILE *));
@@ -265,6 +277,7 @@ extern Responsible *get_responsible_address	PARAMS((char *));
 /* in pr.c */
 extern void read_pr			PARAMS((FILE *, int));
 extern void write_pr			PARAMS((FILE *, PR_Name));
+extern void write_pr_from_index		PARAMS((FILE *, PR_Name, char *));
 extern void init_pr			PARAMS((void));
 extern void clean_pr			PARAMS((void));
 extern char *field_value		PARAMS((PR_Name));
