@@ -28,6 +28,8 @@ char myname[MAXHOSTNAMELEN];
 
 char *program_name;
 
+extern FILE *outfile;
+
 /* If 1, we're running the daemon.  */
 int is_daemon = 1;
 
@@ -679,6 +681,8 @@ main (argc, argv)
   int not_inetd  = 0;
   int access, access_required;
 
+  outfile = stdout;
+
   program_name = basename (argv[0]);
 
   search = (Index *) xmalloc (sizeof (Index));
