@@ -61,15 +61,25 @@ write_index (index_start)
   for (i = index_start; i ; i = i->next) 
     {
 #ifdef GNATS_RELEASE_BASED
-      fprintf(fp, "%s/%s:%s:%s:%s:%s:%s:%s:%d\n", i->category, i->number,
-        i->submitter, i->responsible, i->state, i->confidential,
-        i->severity, i->priority,
-	      (i->date_required && *i->date_required) ? atoi(i->date_required)
-	      : 0);
+      fprintf(fp, "%s/%s|%s|%s|%s|%s|%s|%s|%d|%s|%s|%d|%d|%d|%s|%s|%s|%s\n",
+        i->category,    i->number,   i->submitter,
+        i->responsible, i->state,    i->confidential,
+        i->severity,    i->priority,
+	(i->date_required && *i->date_required) ? atoi(i->date_required) : 0,
+        i->quarter,     i->keywords,
+	(i->arrival_date  && *i->arrival_date)  ? atoi(i->arrival_date)  : 0,
+	(i->last_modified && *i->last_modified) ? atoi(i->last_modified) : 0,
+	(i->closed_date   && *i->closed_date)   ? atoi(i->closed_date)   : 0,
+        i->class, i->originator, i->release, i->synopsis);
 #else
-      fprintf(fp, "%s/%s:%s:%s:%s:%s:%s:%s\n", i->category, i->number,
-        i->submitter, i->responsible, i->state, i->confidential,
-        i->severity, i->priority);
+      fprintf(fp, "%s/%s|%s|%s|%s|%s|%s|%s|%d|%d|%d|%s|%s|%s|%s\n",
+        i->category,    i->number,   i->submitter,
+        i->responsible, i->state,    i->confidential,
+        i->severity,    i->priority,
+	(i->arrival_date  && *i->arrival_date)  ? atoi(i->arrival_date)  : 0,
+	(i->last_modified && *i->last_modified) ? atoi(i->last_modified) : 0,
+	(i->closed_date   && *i->closed_date)   ? atoi(i->closed_date)   : 0,
+        i->class, i->originator, i->release, i->synopsis);
 #endif
     }
 
@@ -110,7 +120,7 @@ add_to_index ()
 {
   FILE *fp;
   char *path = (char *) alloca (PATH_MAX);
-  char *buf = (char *) alloca (STR_MAX);
+  char *buf = (char *) alloca (STR_MAXLONG);
 
   block_signals ();
 
@@ -120,7 +130,7 @@ add_to_index ()
   if (fp == NULL) 
     punt (1, "Can't append to the GNATS index file (%s).", path);
 
-  memset ((void *) buf, 0, sizeof (STR_MAX));
+  memset ((void *) buf, 0, sizeof (STR_MAXLONG));
   create_index_entry (buf);
   fputs (buf, fp);
 
@@ -291,7 +301,8 @@ unlock_gnats ()
     {
       if (is_daemon)
 	{
-	  printf ("%d GNATS is not locked.\r\n", CODE_FILE_ERROR);
+	  printf ("%d Unable to unlock database: %s\r\n", CODE_FILE_ERROR,
+		  strerror(errno));
 	  return -1;
 	}
       else
@@ -302,6 +313,9 @@ unlock_gnats ()
 	}
     }
 
+  if (is_daemon)
+	printf ("%d GNATS database is now unlocked.\r\n", CODE_OK);
+
   return 0;
 }
 
@@ -409,3 +423,44 @@ unblock_signals ()
   signal (SIGABRT, SIG_DFL);
 #endif
 }
+
+char*
+get_prid_from_path (path)
+    char *path;
+{
+  if (!strchr (path, '/'))
+    return (path);
+  return (strrchr (path, '/') + 1);
+}
+
+char*
+get_cat_prid_from_path (path)
+    char *path;
+{
+  int   i = 0;
+  char *p = path + strlen (path);
+  if (!strchr (path, '/'))
+    return (path);
+  while (i < 2)
+  {
+    p--;
+    if (*p == '/')
+      i++;
+  }
+  return (p + 1);
+}
+
+char*
+get_lock_path (fname)
+    char *fname;
+{
+  char *path;
+
+  if (fname == NULL)
+    return NULL;
+
+  path = (char *) xmalloc (PATH_MAX);
+  sprintf (path, "%s/gnats-adm/locks/%s.lock", gnats_root, get_prid_from_path (fname));
+
+  return path;
+}
