@@ -19,7 +19,7 @@
 # along with GNU GNATS; see the file COPYING.  If not, write to
 # the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
-GNATS_ROOT=xGNATS_ROOTx
+GNATS_ROOT=${GNATS_ROOT:-xGNATS_ROOTx}
 GNATS_ADMIN=xGNATS_ADMINx
 MAIL_AGENT="xMAIL_AGENTx"
 [ -r $GNATS_ROOT/gnats-adm/config ] && . $GNATS_ROOT/gnats-adm/config
@@ -70,9 +70,9 @@ __EOF__
       ;;
     *query-pr*)
       query-pr --restricted --state 'o|a|f|s' \
-	`echo $args | sed 's/^.*query-pr//'`;;
+	`echo $args | sed 's/^.*query-pr//'` --directory="$GNATS_ROOT" $*;;
     *)
-      query-pr --restricted --state 'o|a|f|s' $args;;
+      query-pr --restricted --state 'o|a|f|s' $args --directory="$GNATS_ROOT" $*;;
   esac
 else
   echo "To: $GNATS_ADMIN"
