@@ -20,22 +20,48 @@
 # along with GNU GNATS; see the file COPYING.  If not, write to
 # the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
-GNATS_ROOT=xGNATS_ROOTx
+prog=`basename $0`
+USAGE="$prog: [--help] [--directory=gnats_root]"
+
+# process command line options
+while [ $# -gt 0 ]; do
+  case "$1" in
+    -d | --directory)
+      if [ $# -eq 1 ]; then echo "$USAGE"; exit 1; fi
+      shift ; GNATS_ROOT="$1" ;;
+    --directory=*) GNATS_ROOT="`echo $1 | sed 's/^[-a-z]*=//'`" ;;
+    -*)  echo "$USAGE" ; exit 1 ;;
+  esac
+  shift
+done
+
+errmsg="must be set in the environment or on command line
+
+$USAGE"
+
+GNATS_ROOT=${GNATS_ROOT:?$errmsg}
 GNATS_SITE=xGNATS_SITEx
 DATADIR=xDATADIRx
 
+# verify gnats root
+if [ ! -d ${GNATS_ROOT} ] ; then
+   echo "$prog: No GNATS_ROOT directory $GNATS_ROOT!"
+   exit 1
+fi
+
+
 CATEGORIES=`grep -v '^#' $GNATS_ROOT/gnats-adm/categories | sed -e 's/:.*//g'`
 
 # Newer config information?
 [ -f ${GNATS_ROOT}/gnats-adm/config ] && . ${GNATS_ROOT}/gnats-adm/config
 
 if [ ! -d $DATADIR/gnats ]; then
-  echo "$0: No directory $DATADIR/gnats!"
+  echo "$prog: No directory $DATADIR/gnats!"
   exit 1
 fi
 
 if [ ! -d $DATADIR/gnats/dist ]; then
-  echo "$0: No directory $DATADIR/gnats/dist!"
+  echo "$prog: No directory $DATADIR/gnats/dist!"
   exit 1
 fi
 
