@@ -21,6 +21,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
 #include "config.h"
 #include "gnats.h"
 #include "query.h"
+#include "db_conf.h"
 
 void usage (), version ();
 
@@ -36,6 +37,9 @@ int business_time = 0;
 /* If 1, we're running the daemon.  */
 int is_daemon = 0;
 
+/* If 1, we're running a network client.  */
+int is_client = 0;
+
 typedef struct _times
 {
   int days;
@@ -44,6 +48,7 @@ typedef struct _times
 
 struct option long_options[] =
 {
+  {"directory", 1, NULL, 'd'},
   {"business-time", 0, NULL, 'b'},
   {"version", 0, NULL, 'V'},
   {"help", 0, NULL, 'h'},
@@ -74,13 +79,7 @@ report_age (p)
 {
   char *path;
 
-  if (((char *) strchr (p, '/')) == NULL)
-    path = get_category (p);
-  else
-    {
-      path = (char *) xmalloc (PATH_MAX);
-      sprintf (path, "%s/%s", gnats_root, p);
-    }
+  path = lookup_pr_path (p);
 
   if (path)
     {
@@ -101,6 +100,11 @@ report_age (p)
 
       xfree (path);
     }
+  else
+    {
+      fprintf (stderr, "%s: no such PR %s\n", program_name, p);
+      exit (1);
+    }
 }
 
 int
@@ -113,11 +117,15 @@ main (argc, argv)
 
   name = gnats_server;
 
-  while ((optc = getopt_long (argc, argv, "bhV",
+  while ((optc = getopt_long (argc, argv, "bhVd:",
 			      long_options, (int *) 0)) != EOF)
     {
       switch (optc)
 	{
+	case 'd':
+	  gnats_root = optarg;
+	  break;
+
 	case 'b':
 	  business_time = 1;
 	  break;
@@ -139,8 +147,7 @@ main (argc, argv)
   if (optind == argc || optind >= argc)
     usage (1);
 
-  configure ();
-  init_gnats ();
+  init_gnats (program_name);
 
   index_chain = get_index ();
   if (index_chain == NULL)
@@ -150,6 +157,7 @@ main (argc, argv)
     }
 
   report_age (argv[1]);
+  free_db_conf();
   exit (0);
 }
 
@@ -157,7 +165,7 @@ void
 usage (x)
   int x;
 {
-  fprintf (stderr, "Usage: %s [-b] [--business-time] PR\n", program_name);
+  fprintf (stderr, "Usage: %s [-b] [--business-time] [-d gnats_root] PR\n", program_name);
   exit (x);
 }
 
