@@ -28,6 +28,12 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
 
 void usage (), version ();
 
+/* If 1, we're running the daemon.  */
+int is_daemon = 0;
+
+/* If 1, we're running a network client.  */
+int is_client = 0;
+
 /* The name of the GNATS server.  */
 char *name;
 
@@ -44,6 +50,7 @@ struct option long_options[] =
 {
 /*  {"business-time", 0, NULL, 'b'},*/
 /*  {"help", 0, NULL, 'h'},*/
+  {"directory", 1, NULL, 'd'},
   {"version", 0, NULL, 'V'},
   {NULL, 0, NULL, 0}
 };
@@ -102,13 +109,7 @@ do_stat (p)
 {
   char *path;
 
-  if (((char *) strchr (p, '/')) == NULL)
-    path = get_category (p);
-  else
-    {
-      path = (char *) xmalloc (PATH_MAX);
-      sprintf (path, "%s/%s", gnats_root, p);
-    }
+  path = lookup_pr_path (p);
 
   if (path)
     {
@@ -144,7 +145,8 @@ do_category (c)
   char *path = (char *) xmalloc (PATH_MAX);
 
   for (i = index_chain; i ; i = i->next)
-    if (strcmp (i->category, c) == 0 && strcmp (i->state, "closed") == 0)
+    if ((strcmp (i->category, c) == 0)
+        && (check_state_type (i->state, "closed")))
       {
 	sprintf (path, "%s/%s", c, i->number);
 	do_stat (path);
@@ -163,11 +165,15 @@ main (argc, argv)
 
   name = gnats_server;
 
-  while ((optc = getopt_long (argc, argv, "hV",
+  while ((optc = getopt_long (argc, argv, "hVd:",
 			      long_options, (int *) 0)) != EOF)
     {
       switch (optc)
 	{
+	case 'd':
+	  gnats_root = optarg;
+	  break;
+
 	case 'V':
 	  version ();
 	  exit (0);
@@ -185,8 +191,7 @@ main (argc, argv)
   if (optind == argc || optind >= argc)
     usage (1);
 
-  configure ();
-  init_gnats ();
+  init_gnats (program_name);
 
   index_chain = get_index ();
   if (index_chain == NULL)
@@ -212,6 +217,7 @@ main (argc, argv)
   printf ("%-16s %4d           %4d %02d  %4d %02d  %4d %02d\n", c, cnt[c], avgd, avgh, maxd, maxh, mind, minh);
 #endif
 
+  free_db_conf();
   exit (0);
 }
 
@@ -219,7 +225,7 @@ void
 usage (x)
   int x;
 {
-  fprintf (stderr, "Usage: %s category [category...]\n", program_name);
+  fprintf (stderr, "Usage: %s [-d gnats_root] category [category...]\n", program_name);
   exit (x);
 }
 
