@@ -21,6 +21,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
 #include "config.h"
 #include "gnats.h"
 #include "query.h"
+#include "db_conf.h"
 
 /* The name this program was run with.  */
 char *program_name;
@@ -31,6 +32,9 @@ int restricted = 0;
 /* If 1, we're running the daemon.  */
 int is_daemon = 0;
 
+/* If 1, we're running a network client.  */
+int is_client = 0;
+
 struct option long_options[] =
 {
   {"category", 1, NULL, 'c'},
@@ -56,6 +60,7 @@ struct option long_options[] =
   {"severity", 1, NULL, 'e'},
   {"skip-closed", 0, NULL, 'x'},
   {"sql", 0, NULL, 'i'},
+  {"sql2", 0, NULL, 'I'},
   {"state", 1, NULL, 's'},
   {"summary", 0, NULL, 'q'},
   {"submitter", 1, NULL, 'S'},
@@ -66,9 +71,16 @@ struct option long_options[] =
 #endif
   {"arrived-before", 1, NULL, 'b'},
   {"arrived-after", 1, NULL, 'a'},
+  {"modified-before", 1, NULL, 'B'},
+  {"modified-after", 1, NULL, 'M'},
+  {"closed-before", 1, NULL, 'z'},
+  {"closed-after", 1, NULL, 'Z'},
   {"list-categories", 0, NULL, 'j'},
   {"list-responsible", 0, NULL, 'k'},
   {"list-submitters", 0, NULL, 'l'},
+  {"list-states", 0, NULL, 'T'},
+  {"list-classes", 0, NULL, 'J'},
+  {"list-config", 0, NULL, 'G'},
   {"version", 0, NULL, 'V'},
   {NULL, 0, NULL, 0}
 };
@@ -82,14 +94,14 @@ query_pr (p, s)
 {
   char *path;
   Index *i;
-  int found = 0;
+  int opened, found = 0;
 
   if (p == NULL)
     {
       /* We weren't given a list of PRs to check, so we do the
 	 whole shooting match.  */
       for (i = index_chain; i ; i = i->next)
-	if (pr_matches (s, i) && do_pr (i))
+	if (pr_matches (s, i, &opened) && do_pr (i, opened))
 	  {
 	    found = 1;
 	    fprintf (outfile, "\n");
@@ -97,47 +109,23 @@ query_pr (p, s)
     }
   else
     {
-      if (searching || numeric (p))
-	{
-	  char pat[40];
-	  strcpy (pat, p);
-	  strcat (pat, "\\'");
+      char pat[40], *n;
+      if ((n = (char *) strchr (p, '/')) != NULL) /* Remove the category */
+        p = ++n;
+      strcpy (pat, p);
+      strcat (pat, "\\'");
 
-	  for (i = index_chain; i ; i = i->next)
-	    if (regcmp (pat, i->number) == 0)
+      for (i = index_chain; i ; i = i->next)
+        if (regcmp (pat, i->number) == 0)
+	  {
+	    if (pr_matches (s, i, &opened) && do_pr (i, opened))
 	      {
-		if (pr_matches (s, i) && do_pr (i))
-		  {
-		    found = 1;
-		    fprintf (outfile, "\n");
-		  }
+		found = 1;
+		fprintf (outfile, "\n");
 	      }
-	}
-      else
-	{
-	  /* They did a plain query-pr with a list of PRs, just print
-	     this one out.  */
-	  if (((char *) strchr (p, '/')) == NULL)
-	    path = get_category (p);
-	  else
-	    {
-	      path = (char *) xmalloc (PATH_MAX);
-	      sprintf (path, "%s/%s", gnats_root, p);
-	    }
-
-	  if (path)
-	    {
-	      if (do_pr_internal (path, p)
-		  && ! (skip_closed
-			&& strcmp (pr[STATE].value, "closed") == 0))
-		{
-		  found = 1;
-		  print_pr (path, p, 1);
-		  fprintf (outfile, "\n");
-		}		  
-	      xfree (path);
-	    }
-	}
+            /* Only one PR will match this PR number, because it's not really a regexp */
+            break;
+	  }
     }
 
   return !found;
@@ -151,9 +139,10 @@ main (argc, argv)
   int optc;
   Index *s;
   int errors = 0;
-  char *spec_gnats_root = 0;
   int formats = 0, lists = 0;
 
+  outfile = stdout;
+  
   program_name = basename (argv[0]);
   if (argc == 1)
     usage (1);
@@ -162,21 +151,22 @@ main (argc, argv)
   memset (s, 0, sizeof (Index));
 
 #ifdef GNATS_RELEASE_BASED
-  while ((optc = getopt_long (argc, argv, "A:a:c:C:D:d:e:K:L:m:o:O:p:PQ:s:S:r:t:u:U:y:VFixhqRjkl",
+  while ((optc = getopt_long (argc, argv, "A:a:B:b:c:C:D:d:e:K:L:M:m:o:O:p:PQ:s:S:r:t:u:U:y:z:Z:VFGiIxhqRjJklT",
 #else
-  while ((optc = getopt_long (argc, argv, "A:b:c:C:D:d:e:L:m:o:O:p:Ps:S:r:t:u:U:y:VFixhqRjkl",
+  while ((optc = getopt_long (argc, argv, "A:a:B:b:c:C:D:d:e:K:L:M:m:o:O:p:Ps:S:r:t:u:U:y:z:Z:VFGiIxhqRjJklT",
 #endif
 			      long_options, (int *) 0)) != EOF)
     {
       switch (optc)
 	{
 	case 'A':
-	  release = optarg;
+	  s->release = optarg;
 	  searching = 1;
 	  break;
 
 	case 'a':
 	  arrived_after = get_date (optarg, NULL);
+	  searching = 1;
 	  if (arrived_after < 0)
 	    {
 	      fprintf (stderr, "%s: could not decypher `%s'\n",
@@ -187,7 +177,52 @@ main (argc, argv)
 
 	case 'b':
 	  arrived_before = get_date (optarg, NULL);
-	  if (arrived_after < 0)
+	  searching = 1;
+	  if (arrived_before < 0)
+	    {
+	      fprintf (stderr, "%s: could not decypher `%s'\n",
+		       program_name, optarg);
+	      exit (1);
+	    }
+	  break;
+
+	case 'Z':
+	  closed_after = get_date (optarg, NULL);
+	  searching = 1;
+	  if (closed_after < 0)
+	    {
+	      fprintf (stderr, "%s: could not decypher `%s'\n",
+		       program_name, optarg);
+	      exit (1);
+	    }
+	  break;
+
+	case 'z':
+	  closed_before = get_date (optarg, NULL);
+	  searching = 1;
+	  if (closed_before < 0)
+	    {
+	      fprintf (stderr, "%s: could not decypher `%s'\n",
+		       program_name, optarg);
+	      exit (1);
+	    }
+	  break;
+
+	case 'M':
+	  modified_after = get_date (optarg, NULL);
+	  searching = 1;
+	  if (modified_after < 0)
+	    {
+	      fprintf (stderr, "%s: could not decypher `%s'\n",
+		       program_name, optarg);
+	      exit (1);
+	    }
+	  break;
+
+	case 'B':
+	  modified_before = get_date (optarg, NULL);
+	  searching = 1;
+	  if (modified_before < 0)
 	    {
 	      fprintf (stderr, "%s: could not decypher `%s'\n",
 		       program_name, optarg);
@@ -196,7 +231,7 @@ main (argc, argv)
 	  break;
 
 	case 'd':
-	  spec_gnats_root = optarg;
+	  gnats_root = optarg;
 	  break;
 
 	case 'o':
@@ -243,25 +278,30 @@ main (argc, argv)
 	  break;
 
 	case 'L':
-	  class = optarg;
+	  s->class = optarg;
+	  searching = 1;
 	  break;
 
 #ifdef GNATS_RELEASE_BASED
 	case 'Q':
-	  quarter = optarg;
+	  s->quarter = optarg;
+	  searching = 1;
 	  break;
 
 	case 'K':
-	  keywords = optarg;
+	  s->keywords = optarg;
+	  searching = 1;
 	  break;
 #endif
 
 	case 'm':
 	  m_text_search = optarg;
+	  searching = 1;
 	  break;
 
 	case 'O':
-	  originator = optarg;
+	  s->originator = optarg;
+	  searching = 1;
 	  break;
 
 	case 'p':
@@ -285,6 +325,7 @@ main (argc, argv)
 
 	case 't':
 	  text_search = optarg;
+	  searching = 1;
 	  break;
 
 	case 'V':
@@ -302,6 +343,11 @@ main (argc, argv)
 	  formats++;
 	  break;
 
+	case 'I':
+	  query_format = FORMAT_SQL2;
+	  formats++;
+	  break;
+
 	case 'q':
 	  query_format = FORMAT_SUMM;
 	  formats++;
@@ -326,32 +372,47 @@ main (argc, argv)
 	  lists++;
 	  break;
 
+	case 'T':
+	  list_format = LIST_STATES;
+	  lists++;
+	  break;
+
+	case 'J':
+	  list_format = LIST_CLASSES;
+	  lists++;
+	  break;
+
+	case 'G':
+	  list_format = LIST_CONFIG;
+	  lists++;
+	  break;
+
 #ifdef GNATS_RELEASE_BASED
 	case 'u':
 	  required_before = get_date (optarg, NULL);
+	  searching = 1;
 	  if (required_before < 0)
 	    {
 	      fprintf (stderr, "%s: could not decypher `%s'\n",
 		       program_name, optarg);
 	      exit (1);
 	    }
-	  searching = 1;
 	  break;
 
 	case 'U':
 	  required_after = get_date (optarg, NULL);
+	  searching = 1;
 	  if (required_after < 0)
 	    {
 	      fprintf (stderr, "%s: could not decypher `%s'\n",
 		       program_name, optarg);
 	      exit (1);
 	    }
-	  searching = 1;
 	  break;
 #endif
 
 	case 'y':
-	  synopsis = optarg;
+	  s->synopsis = optarg;
 	  searching = 1;
 	  break;
 
@@ -364,9 +425,6 @@ main (argc, argv)
 	}
     }
 
-  if (spec_gnats_root && !restricted)
-    gnats_root = spec_gnats_root;
-
   if (formats > 1)
     {
       fprintf (stderr, "%s: only one of -i, -F, or -q may be specified\n",
@@ -376,13 +434,12 @@ main (argc, argv)
 
   if (lists > 1)
     {
-      fprintf (stderr, "%s: only one of -j, -k, or -l may be specified alone\n",
+      fprintf (stderr, "%s: only one list option may be specified\n",
 	       program_name);
       exit (4);
     }
 
-  configure ();
-  init_gnats ();
+  init_gnats (program_name);
 
   if (lists)
     {
@@ -396,11 +453,11 @@ main (argc, argv)
   quiet = 1;
 
   index_chain = get_index ();
-  if (index_chain == NULL)
-    {
-      fprintf (stderr, "%s: couldn't read the index\n", program_name);
-      exit (1);
-    }
+/*   if (index_chain == NULL) */
+/*     { */
+/*       fprintf (stderr, "%s: couldn't read the index\n", program_name); */
+/*       exit (1); */
+/*     } */
 
   if (optind == argc)
     {
@@ -419,6 +476,7 @@ main (argc, argv)
     fprintf (stderr, "%s: no PRs matched\n", program_name);
 
   /* Exit non-zero if there were any troubles.  */
+  free_db_conf();			      
   exit (errors != 0);
 }
 
@@ -428,9 +486,10 @@ usage (s)
 {
 #ifdef GNATS_RELEASE_BASED
   fprintf (stderr, "\
-Usage: %s [-FhiPRqVx] [-C confidential] [-c category] [-d directory]\n\
+Usage: %s [-FGhiPRqVx] [-C confidential] [-c category] [-d directory]\n\
        [-e severity] [-m mtext] [-O originator] [-o outfile] [-p priority]\n\
        [-L class] [-r responsible] [-S submitter] [-s state] [-t text]\n\
+       [-b date] [-a date] [-B date] [-M date] [-z date] [-Z date]\n\
        [-y synopsis] [-A release] [--full] [--help] [--print-path] [--version]\n\
        [--summary] [--sql] [--skip-closed] [--category=category]\n\
        [--confidential=yes|no] [--directory=directory] [--output=outfile]\n\
@@ -439,23 +498,30 @@ Usage: %s [-FhiPRqVx] [-C confidential] [-c category] [-d directory]\n\
        [--quarter=quarter] [--keywords=regexp]\n\
        [--required-before=date] [--required-after=date]\n\
        [--arrived-before=date] [--arrived-after=date]\n\
+       [--modified-before=date] [--modified-after=date]\n\
+       [--closed-before=date] [--closed-after=date]\n\
        [--severity=severity] [--state=state] [--submitter=submitter]\n\
-       [--list-categories] [--list-responsible] [--list-submitters]\n\
+       [--list-categories] [--list-classes] [--list-responsible]\n\
+       [--list-states] [--list-submitters] [--list-config]\n\
        [--synopsis=synopsis] [--text=text] [--multitext=mtext] [PR] [PR]...\n",
 	   program_name);
 #else
   fprintf (stderr, "\
-Usage: %s [-FhiPRqVx] [-C confidential] [-c category] [-d directory]\n\
+Usage: %s [-FGhiPRqVx] [-C confidential] [-c category] [-d directory]\n\
        [-e severity] [-m mtext] [-O originator] [-o outfile] [-p priority]\n\
        [-L class] [-r responsible] [-S submitter] [-s state] [-t text]\n\
+       [-b date] [-a date] [-B date] [-M date] [-z date] [-Z date]\n\
        [-y synopsis] [-A release] [--full] [--help] [--print-path] [--version]\n\
        [--summary] [--sql] [--skip-closed] [--category=category]\n\
        [--confidential=yes|no] [--directory=directory] [--output=outfile]\n\
        [--originator=name] [--priority=level] [--class=class]\n\
        [--responsible=person] [--release=release] [--restricted]\n\
        [--arrived-before=date] [--arrived-after=date]\n\
+       [--modified-before=date] [--modified-after=date]\n\
+       [--closed-before=date] [--closed-after=date]\n\
        [--severity=severity] [--state=state] [--submitter=submitter]\n\
-       [--list-categories] [--list-responsible] [--list-submitters]\n\
+       [--list-categories] [--list-classes] [--list-responsible]\n\
+       [--list-states] [--list-submitters] [--list-config]\n\
        [--synopsis=synopsis] [--text=text] [--multitext=mtext] [PR] [PR]...\n",
 	   program_name);
 #endif
