@@ -18,6 +18,8 @@ You should have received a copy of the GNU General Public License
 along with GNU GNATS; see the file COPYING.  If not, write to the Free
 Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
 
+/* If 1, emit info for a SQL2 database.  */
+#define FORMAT_SQL2	(1<<5)
 /* The normal format for a PR.  */
 #define FORMAT_REG	(1<<4)
 /* A summarized, one-line result.  */
@@ -33,6 +35,12 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
 #define LIST_SUBMITTERS	(1<<2)
 /* Query the list of responsible.  */
 #define LIST_RESPONSIBLE (1<<3)
+/* Query the list of states.  */
+#define LIST_STATES (1<<4)
+/* Query the list of classes.  */
+#define LIST_CLASSES (1<<5)
+/* Query the gnats config file.  */
+#define LIST_CONFIG (1<<6)
 
 #define MAXLINE 512
 
@@ -60,6 +68,18 @@ extern time_t arrived_before;
 /* Look for PRs that arrived after this date.  */
 extern time_t arrived_after;
 
+/* Look for PRs which were closed before this date.  */
+extern time_t closed_before;
+
+/* Look for PRs which were closed after this date.  */
+extern time_t closed_after;
+
+/* Look for PRs which were modified before this date.  */
+extern time_t modified_before;
+
+/* Look for PRs which were modified after this date.  */
+extern time_t modified_after;
+
 #ifdef GNATS_RELEASE_BASED
 /* Look for PRs required before this date.  */
 extern time_t required_before;
@@ -123,8 +143,11 @@ extern FILE *outfp;
 extern char *host_name;
 extern int port;
 
-/* The name of the host talking with us.  */
+/* The name and IP address of the host talking with us and their access level.  */
 extern char *current_host;
+extern char *current_addr;
+extern int   user_access;
+extern int   host_access;
 
 /* Where the results should go, if requested.  */
 extern FILE *outfile;
@@ -133,14 +156,16 @@ extern FILE *outfile;
 extern char *disbar			PARAMS((char *));
 extern int sql_types			PARAMS((char *, Sql_Types));
 extern char *sql_time			PARAMS((char *));
+extern char *sql_time_from_index	PARAMS((char *));
 extern char *make_path			PARAMS((char *, char *));
 extern int numeric			PARAMS((char *));
 extern int regcmp			PARAMS((char *, char *));
 extern int regfind			PARAMS((char *, char *));
 extern char *get_category		PARAMS((char *));
-extern int pr_matches			PARAMS((Index *, Index *));
-extern int check_text			PARAMS((void));
+extern int pr_matches			PARAMS((Index *, Index *, int *));
+extern int check_text			PARAMS((Index *, Index *));
+extern int check_mtext			PARAMS((void));
 extern int get_pr			PARAMS((char *, char *, int));
-extern int do_pr			PARAMS((Index *));
-extern int do_pr_internal		PARAMS((char *, char *));
-extern void print_pr			PARAMS((char *, char *, int));
+extern int do_pr			PARAMS((Index *, int));
+/* extern int do_pr_internal		PARAMS((char *, char *)); */
+extern int print_pr			PARAMS((char *, char *, int, Index *));
