@@ -52,6 +52,9 @@ char *queue_dir;
 /* If 1, we're running the daemon.  */
 int is_daemon = 0;
 
+/* If 1, we're running a network client.  */
+int is_client = 0;
+
 struct option long_options[] =
 {
   {"directory", 1, NULL, 'd'},
@@ -360,7 +363,7 @@ main (argc, argv)
 	}
     }
 
-  configure ();
+  init_gnats (program_name);
   umask (022);
 
   if (! gnats_root)
